camelot.camelot.view.controls.delegates.DateColumnDelegate

Package camelot :: Package camelot :: Package view :: Package controls :: Module delegates :: Class DateColumnDelegate |
[hide private]
[frames] | no frames]

# Class DateColumnDelegate

source code

Custom delegate for date values

Instance Methods | [hide private]
__init__(self, format='dd/MM/yyyy', default=None, nullable=True, parent=None) | source code
createEditor(self, parent, option, index) | source code
commitAndCloseEditor(self) | source code
setEditorData(self, editor, index) | source code
setModelData(self, editor, model, index) | source code